<?php

/**
 * @file
 * Forms for creating, editing, and deleting payments.
 */

/**
 * Form callback: create or edit a payment.
 *
 * @param $payment
 *   The payment object to edit or for a create form an empty payment object
 *     with only a payment type defined.
 * @todo
 *   Add validation for this form.
 */
function pgapi_payment_form($form, &$form_state, $payment) {

  // Add the field related form elements.
  $form_state['payment'] = $payment;

  $form['txnid'] = array(
    '#type' => 'hidden',
    '#title' => t('Payment ID'),
    '#description' => t('Supply a unique digital identifier for this payment.'),
    '#default_value' => $payment->txnid,
    '#weight' => -10,
  );

  $form['title'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#default_value' => $payment->title,
    '#maxlength' => 255,
    '#required' => TRUE,
    '#weight' => 5,
  );

  // TODO: Autocomplit field by User Name
  $form['uid'] = array(
    '#type' => 'textfield',
    '#title' => t('User ID'),
    '#description' => t('User name who create this payment.'),
    '#default_value' => $payment->uid,
    '#maxlength' => 255,
    '#required' => TRUE,
    '#weight' => 10,
  );

  $form['amount'] = array(
    '#type' => 'textfield',
    '#title' => t('Amount'),
    '#default_value' => $payment->amount,
    '#maxlength' => 255,
    '#required' => TRUE,
    '#weight' => 15,
  );

  // $form['service'] = array();
  // $form['gateway'] = array();

  $form['description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#default_value' => $payment->description,
    '#weight' => 20,
  );

  $form['status'] = array(
    '#type' => 'select',
    '#title' => t('Status'),
    '#options' => array(
      '1' => t('Pending'),
      '2' => t('Complited'),
      '3' => t('Failed'),
      '4' => t('Denied'),
      '5' => t('Refunded'),
      '6' => t('Canceled'),
      '7' => t('Received'),
    ),
    '#default_value' => $payment->status,
    '#required' => TRUE,
    '#weight' => 25,
  );

  $form['workflow'] = array(
    '#type' => 'select',
    '#title' => t('Workflow'),
    '#options' => array(
      '1' => t('Received'),
      '2' => t('Invoiced'),
      '3' => t('Shipped'),
      '4' => t('Awaiting Response'),
      '5' => t('Canceled'),
      '6' => t('Complited'),
      '6' => t('Security Violation'),
    ),
    '#default_value' => $payment->workflow,
    '#required' => TRUE,
    '#weight' => 25,
  );

  $form['dates_info'] = array(
    '#markup' => t('Created Date: ') . format_date($payment->created, 'long') . '<br>' . t('Changed Date: ') . format_date($payment->changed, 'long'),
    '#weight' => 30,
  );

  $form['actions'] = array(
    '#type' => 'container',
    '#attributes' => array('class' => array('form-actions')),
    '#weight' => 400,
  );

  // We add the form's #submit array to this button along with the actual submit
  // handler to preserve any submit handlers added by a form callback_wrapper.
  $submit = array();

  if (!empty($form['#submit'])) {
    $submit += $form['#submit'];
  }

  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save payment'),
    '#submit' => array_merge($submit, array('pgapi_payment_form_submit')),
  );

  // $form['#validate'][] = 'pgapi_payment_form_validate';

  return $form;
}

/**
 * Submit callback for pgapi_payment_form().
 */
function pgapi_payment_form_submit($form, &$form_state) {
  $payment = & $form_state['payment'];

  // Save default parameters back into the $payment object.
  $payment->title = $form_state['values']['title'];
  $payment->amount = $form_state['values']['amount'];
  $payment->uid = $form_state['values']['uid'];
  // payment->service = $form_state['values']['service'];
  // payment->gateway = $form_state['values']['gateway'];
  $payment->description = $form_state['values']['description'];
  $payment->status = $form_state['values']['status'];
  $payment->workflow = $form_state['values']['workflow'];
  $payment->changed = time();

  // Save the transaction.
  pgapi_transaction_save($payment);

  // Redirect based on the button clicked.
  drupal_set_message(t('Payment ID %payment_id saved.', array('%payment_id' => $payment->txnid)));
}

/**
 * Form callback: confirmation form for deleting a payment.
 *
 * @param $product
 *   The payment object to be deleted.
 *
 * @see confirm_form()
 */
function pgapi_ui_payment_delete_form($form, &$form_state, $payment) {
  $form_state['payment'] = $payment;

  // Ensure this include file is loaded when the form is rebuilt from the cache.
  $form_state['build_info']['files']['form'] = drupal_get_path('module', 'pgapi') . '/includes/pgapi.forms.inc';

  $form['#submit'][] = 'pgapi_payment_delete_form_submit';

  // $content = entity_view('payment', array($ppayment->txnid => $payment));

  $form = confirm_form($form, t('Are you sure you want to delete %title?', array('%title' => $product->title)), '', drupal_render($content) . '<p>' . t('Deleting this payment cannot be undone.', array('@payment_id' => $payment->txnid)) . '</p>', t('Delete'), t('Cancel'), 'confirm');

  return $form;
}

/**
 * Submit callback for pgapi_payment_delete_form().
 */
function pgapi_payment_delete_form_submit($form, &$form_state) {
  $payment = $form_state['payment'];

  if (pgapi_transaction_delete($payment->txnid)) {
    drupal_set_message(t('Payment ID %payment_id has been deleted.', array('%payment_id' => $payment->txnid)));
    watchdog('commerce_product', 'Deleted payment %title (ID: @txnid).', array(
      '%title' => $payment->title,
      '@txnid' => $paymeny->txnid
    ), WATCHDOG_NOTICE);
  }
  else {
    drupal_set_message(t('Payment ID %payment_id could not be deleted.', array('%payment_id' => $payment->txnid)), 'error');
  }
}
