<?php

/**
 * @file
 * Contains the basic transaction field handler.
 */

/**
 * Field handler to provide simple renderer that allows linking to a transaction.
 */
class pgapi_handler_field_transaction extends views_handler_field {
  function init(&$view, &$options) {
    parent::init($view, $options);

    if (!empty($this->options['link_to_transaction'])) {
      $this->additional_fields['txnid'] = 'txnid';
    }
  }

  function option_definition() {
    $options = parent::option_definition();

    $options['link_to_transaction'] = array('default' => FALSE);

    return $options;
  }

  /**
   * Provide the link to transaction option.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['link_to_transaction'] = array(
      '#title' => t("Link this field to the transaction's administrative view page"),
      '#description' => t('This will override any other link you have set.'),
      '#type' => 'checkbox',
      '#default_value' => !empty($this->options['link_to_transaction']),
    );
  }

  /**
   * Render whatever the data is as a link to the transaction.
   *
   * Data should be made XSS safe prior to calling this function.
   */
  function render_link($data, $values) {
    if (!empty($this->options['link_to_transaction']) && $data !== NULL && $data !== '') {
      $transaction_id = $this->get_value($values, 'txnid');
      $this->options['alter']['make_link'] = TRUE;
      $this->options['alter']['path'] = 'admin/pgapi/payments/' . $transaction_id;
    }

    return $data;
  }

  function render($values) {
    $value = $this->get_value($values);
    return $this->render_link($this->sanitize_value($value), $values);
  }
}
