<?php

/**
 * @file
 * Export PGAPI payments to Views
 */

/**
 * Implements hook_views_data()
 */
function pgapi_views_data() {
  $data = array();

  $data['pgapi_transaction']['table']['group'] = t('Payment Transaction');

  $data['pgapi_transaction']['table']['base'] = array(
    'field' => 'txnid',
    'title' => t('Payment Transaction'),
    'access query tag' => 'node_access',
  );
  // $data['pgapi_transaction']['table']['entity type'] = 'pgapi_transaction';

  // Expose the transaction ID.
  $data['pgapi_transaction']['txnid'] = array(
    'title' => t('Transaction ID'),
    'help' => t('The unique internal identifier of the transaction.'),
    'field' => array(
      'handler' => 'pgapi_handler_field_transaction',
      'click sortable' => TRUE,
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );

  // Expose the payment title.
  $data['pgapi_transaction']['title'] = array(
    'title' => t('Title'),
    'help' => t('The title of the transaction used for administrative display.'),
    'field' => array(
      'handler' => 'pgapi_handler_field_transaction',
      'click sortable' => TRUE,
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_string',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_string',
    ),
  );

  // Expose the payment amount.
  $data['pgapi_transaction']['amount'] = array(
    'title' => t('Payment amount'),
    'help' => t('The sum of created transaction payment.'),
    'field' => array(
      'handler' => 'pgapi_handler_field_transaction',
      'click sortable' => TRUE,
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );

  // Expose the creator uid.
  $data['pgapi_transaction']['uid'] = array(
    'title' => t('Creator'),
    'help' => t('Relate a payment to the user who created it.'),
    'relationship' => array(
      'handler' => 'views_handler_relationship',
      'base' => 'users',
      'field' => 'uid',
      'label' => t('Payment creator'),
    ),
  );

  // Expose the payment status.
  $data['pgapi_transaction']['status'] = array(
    'title' => t('Status'),
    'help' => t('Current status of payment transaction.'),
    'field' => array(
      'handler' => 'pgapi_handler_field_payment_status',
      'click sortable' => TRUE,
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );

  // Expose the created and changed timestamps.
  $data['pgapi_transaction']['created'] = array(
    'title' => t('Created date'),
    'help' => t('The date the payment was created.'),
    'field' => array(
      'handler' => 'views_handler_field_date',
      'click sortable' => TRUE,
    ),
    'sort' => array(
      'handler' => 'views_handler_sort_date',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_date',
    ),
  );

  $data['pgapi_transaction']['changed'] = array(
    'title' => t('Updated date'),
    'help' => t('The date the payment was last updated.'),
    'field' => array(
      'handler' => 'views_handler_field_date',
      'click sortable' => TRUE,
    ),
    'sort' => array(
      'handler' => 'views_handler_sort_date',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_date',
    ),
  );

  // Expose links to operate on the payment.
  $data['pgapi_transaction']['view_transaction'] = array(
    'field' => array(
      'title' => t('Link'),
      'help' => t('Provide a simple link to the administrator view of the payment.'),
      'handler' => 'pgapi_handler_field_transaction_link',
    ),
  );
  $data['pgapi_transaction']['edit_transaction'] = array(
    'field' => array(
      'title' => t('Edit link'),
      'help' => t('Provide a simple link to edit the payment.'),
      'handler' => 'pgapi_handler_field_transaction_link_edit',
    ),
  );
  $data['pgapi_transaction']['delete_transaction'] = array(
    'field' => array(
      'title' => t('Delete link'),
      'help' => t('Provide a simple link to delete the payment.'),
      'handler' => 'pgapi_handler_field_transaction_link_delete',
    ),
  );

  $data['pgapi_transaction']['operations'] = array(
    'field' => array(
      'title' => t('Operations links'),
      'help' => t('Display all the available operations links for the payment transaction.'),
      'handler' => 'pgapi_handler_field_transaction_operations',
    ),
  );

  return $data;
}
